@@ -8,6 +8,7 @@
 
 var path = require('path'),
     winston = require('../../../lib/winston');
+const testLogFixturesPath = path.join(__dirname, '..', '..', 'fixtures', 'logs');
 
 winston.exitOnError = function (err) {
   process.stdout.write(err.message);
@@ -16,7 +17,7 @@ winston.exitOnError = function (err) {
 
 winston.handleExceptions([
   new winston.transports.File({
-    filename: path.join(__dirname, '..', 'logs', 'exit-on-error.log'),
+    filename: path.join(testLogFixturesPath, 'exit-on-error.log'),
     handleExceptions: true
   })
 ]);
